Summary:        Flexible, stable and highly-configurable FTP server
Name:           proftpd
Version:        1.3.4a
Release:        1%{?dist}
License:        GPLv2+
Group:          System Environment/Daemons
URL:            http://www.proftpd.org/
Source0:        ftp://ftp.proftpd.org/distrib/source/proftpd-%{version}.tar.bz2
Source1:        proftpd.conf
Source2:        proftpd.init
Source3:        proftpd.pam
Source4:        proftpd.logrotate
Source5:        proftpd.sysconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/service, /sbin/chkconfig, coreutils, findutils
Requires(postun): /sbin/service
BuildRequires:  pam-devel, ncurses-devel, pkgconfig, gettext, zlib-devel
BuildRequires:  openssl-devel, libacl-devel, libcap-devel, /usr/include/tcpd.h
BuildRequires:  openldap-devel, mysql-devel, postgresql-devel
Provides:       ftpserver

%description
ProFTPD is an enhanced FTP server with a focus toward simplicity, security,
and ease of configuration. It features a very Apache-like configuration
syntax, and a highly customizable server infrastructure, including support for
multiple 'virtual' FTP servers, anonymous FTP, and permission-based directory
visibility.

%package ldap
Summary: Module to add LDAP support to the ProFTPD FTP server
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}

%description ldap
Module to add LDAP support to the ProFTPD FTP server.

%package mysql
Summary: Module to add MySQL support to the ProFTPD FTP server
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}

%description mysql
Module to add MySQL support to the ProFTPD FTP server.

%package postgresql
Summary: Module to add PostgreSQL support to the ProFTPD FTP server
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}

%description postgresql
Module to add PostgreSQL support to the ProFTPD FTP server.

%prep
%setup -q -n %{name}-%{version}%{?prever}

# Avoid documentation name conflicts
mv contrib/README contrib/README.contrib

# Avoid docfile dependencies
chmod -x contrib/xferstats.holger-preiss

# Fix character encoding in docs
for f in ChangeLog; do
    iconv -f iso-8859-1 -t utf-8 < ${f} > ${f}.utf-8
    mv -f ${f}.utf-8 ${f}
done

%build

# Modules to be built as DSO's (excluding mod_ifsession, always specified last)
SMOD1=mod_sql:mod_sql_passwd:mod_sql_mysql:mod_sql_postgres
SMOD2=mod_quotatab:mod_quotatab_file:mod_quotatab_ldap:mod_quotatab_radius:mod_quotatab_sql
SMOD3=mod_ldap:mod_ban:mod_wrap:mod_ctrls_admin:mod_facl:mod_load
SMOD4=mod_radius:mod_ratio:mod_rewrite:mod_site_misc:mod_exec:mod_shaper
SMOD5=mod_wrap2:mod_wrap2_file:mod_wrap2_sql
SMOD6=mod_sftp:mod_sftp_pam:mod_sftp_sql:mod_tls_shmcache

%configure \
    --libexecdir="%{_libexecdir}/proftpd" \
    --localstatedir="%{_localstatedir}/run/proftpd" \
    --disable-strip \
    --enable-ctrls \
    --enable-dso \
    --enable-facl \
    --enable-ipv6 \
    --enable-nls \
    --enable-openssl \
    --enable-shadow \
    --with-libraries="%{_libdir}/mysql" \
    --with-includes="%{_includedir}/mysql" \
    --with-modules=mod_readme:mod_auth_pam:mod_tls \
    --with-shared=${SMOD1}:${SMOD2}:${SMOD3}:${SMOD4}:${SMOD5}:${SMOD6}:mod_ifsession

make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} \
    rundir="%{_localstatedir}/run/proftpd" \
    INSTALL_USER=`id -un` \
    INSTALL_GROUP=`id -gn`
install -D -p -m 640 %{SOURCE1} %{buildroot}%{_sysconfdir}/proftpd.conf
install -D -p -m 755 %{SOURCE2} %{buildroot}%{_sysconfdir}/rc.d/init.d/proftpd
install -D -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/pam.d/proftpd
install -D -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/proftpd
install -D -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/proftpd
mkdir -p %{buildroot}%{_localstatedir}/{ftp/{pub,uploads},log/proftpd}
mkdir -p %{buildroot}%{_sysconfdir}/proftpd.d

# Remove unwanted tools
rm -f %{buildroot}%{_bindir}/ftpmail
rm -f %{buildroot}%{_mandir}/man1/ftpmail.1*

# Find translations
%find_lang proftpd

%clean
rm -rf %{buildroot}

%post
if [ $1 -eq 1 ]; then
    /sbin/chkconfig --add proftpd
fi

%preun
if [ $1 -eq 0 ]; then
    /sbin/service proftpd stop &>/dev/null || :
    /sbin/chkconfig --del proftpd || :
    find %{_localstatedir}/run/proftpd -depth -mindepth 1 |
        xargs rm -rf &>/dev/null || :
fi

%postun
if [ $1 -ge 1 ]; then
    /sbin/service proftpd condrestart &>/dev/null || :
fi

%files -f proftpd.lang
%defattr(-,root,root,-)
%doc COPYING CREDITS ChangeLog NEWS README
%doc README.DSO README.modules README.IPv6 README.PAM
%doc README.capabilities README.classes README.controls README.facl
%doc contrib/README.contrib contrib/README.ratio
%doc doc/* sample-configurations/ contrib/xferstats.holger-preiss
%dir %{_localstatedir}/ftp/
%dir %{_localstatedir}/ftp/pub/
%dir %{_localstatedir}/run/proftpd/
%dir %{_sysconfdir}/proftpd.d
%config(noreplace) %{_sysconfdir}/blacklist.dat
%config(noreplace) %{_sysconfdir}/dhparams.pem
%config(noreplace) %{_sysconfdir}/logrotate.d/proftpd
%config(noreplace) %{_sysconfdir}/pam.d/proftpd
%config(noreplace) %{_sysconfdir}/proftpd.conf
%config(noreplace) %{_sysconfdir}/sysconfig/proftpd
%{_sysconfdir}/rc.d/init.d/proftpd
%{_bindir}/ftpasswd
%{_bindir}/ftpcount
%{_bindir}/ftpdctl
%{_bindir}/ftpquota
%{_bindir}/ftptop
%{_bindir}/ftpwho
%exclude %{_bindir}/prxs
%{_sbindir}/ftpscrub
%{_sbindir}/ftpshut
%{_sbindir}/in.proftpd
%{_sbindir}/proftpd
%{_mandir}/man1/ftpasswd.1*
%{_mandir}/man1/ftpcount.1*
%{_mandir}/man1/ftpquota.1*
%{_mandir}/man1/ftptop.1*
%{_mandir}/man1/ftpwho.1*
%{_mandir}/man5/xferlog.5*
%{_mandir}/man8/ftpdctl.8*
%{_mandir}/man8/ftpscrub.8*
%{_mandir}/man8/ftpshut.8*
%{_mandir}/man8/proftpd.8*
%exclude %{_includedir}/proftpd/
%exclude %{_libdir}/pkgconfig/
%dir %{_libexecdir}/proftpd/
%{_libexecdir}/proftpd/mod_ban.so
%{_libexecdir}/proftpd/mod_ctrls_admin.so
%{_libexecdir}/proftpd/mod_exec.so
%{_libexecdir}/proftpd/mod_facl.so
%{_libexecdir}/proftpd/mod_ifsession.so
%{_libexecdir}/proftpd/mod_load.so
%{_libexecdir}/proftpd/mod_quotatab.so
%{_libexecdir}/proftpd/mod_quotatab_file.so
%{_libexecdir}/proftpd/mod_quotatab_radius.so
%{_libexecdir}/proftpd/mod_quotatab_sql.so
%{_libexecdir}/proftpd/mod_radius.so
%{_libexecdir}/proftpd/mod_ratio.so
%{_libexecdir}/proftpd/mod_rewrite.so
%{_libexecdir}/proftpd/mod_sftp.so
%{_libexecdir}/proftpd/mod_sftp_pam.so
%{_libexecdir}/proftpd/mod_sftp_sql.so
%{_libexecdir}/proftpd/mod_shaper.so
%{_libexecdir}/proftpd/mod_site_misc.so
%{_libexecdir}/proftpd/mod_sql.so
%{_libexecdir}/proftpd/mod_sql_passwd.so
%{_libexecdir}/proftpd/mod_tls_shmcache.so
%{_libexecdir}/proftpd/mod_wrap.so
%{_libexecdir}/proftpd/mod_wrap2.so
%{_libexecdir}/proftpd/mod_wrap2_file.so
%{_libexecdir}/proftpd/mod_wrap2_sql.so
%exclude %{_libexecdir}/proftpd/*.a
%exclude %{_libexecdir}/proftpd/*.la
%attr(331, ftp, ftp) %dir %{_localstatedir}/ftp/uploads/
%attr(750, root, root) %dir %{_localstatedir}/log/proftpd/

%files ldap
%defattr(-,root,root,-)
%doc README.LDAP contrib/mod_quotatab_ldap.ldif contrib/mod_quotatab_ldap.schema
%{_libexecdir}/proftpd/mod_ldap.so
%{_libexecdir}/proftpd/mod_quotatab_ldap.so

%files mysql
%defattr(-,root,root,-)
%{_libexecdir}/proftpd/mod_sql_mysql.so

%files postgresql
%defattr(-,root,root,-)
%{_libexecdir}/proftpd/mod_sql_postgres.so

%changelog
* Wed Feb  8 2012 ClearFoundation <developer@clearfoundation.com> 1.3.4a-1
- Updated to 1.3.4a

* Wed Nov 16 2011 ClearFoundation <developer@clearfoundation.com> 1.3.3g-1
- Bumped to latest 1.3.3x release 

* Fri Nov 04 2011 ClearFoundation <developer@clearfoundation.com> 1.3.3f-2
- Changed PAM list file location

* Mon Oct 31 2011 ClearFoundation <developer@clearfoundation.com> 1.3.3f-1
- Imported from EPEL and tweaked for ClearOS
